# -*- coding: utf-8 -*-

from django import forms
from django.forms.utils import ErrorList

from portailuser.fields import PortailUserField

from evenements.models import Evenement


class EvenementForm(forms.ModelForm):
    responsable = PortailUserField(help_text="Laissez vide pour utiliser votre nom", required=False)
    # image = forms.ImageField(label="Image", required=True)

    class Meta:
        model = Evenement
        fields = (
            "nom",
            "description",
            "date_heure_debut",
            "date_heure_fin",
            "lieu",
            "responsable",
        )

    def clean(self):
        cleaned_data = self.cleaned_data
        date_heure_debut = cleaned_data.get("date_heure_debut")
        date_heure_fin = cleaned_data.get("date_heure_fin")

        if date_heure_debut > date_heure_fin:
            self._errors["date_heure_debut"] = ErrorList(["Date / heure de début supérieure à date / heure de fin"])
            self._errors["date_heure_fin"] = ErrorList(["Date / heure de fin inférieure à date / heure de début"])
            del cleaned_data["date_heure_debut"]
            del cleaned_data["date_heure_fin"]

        return cleaned_data
